<?php
date_default_timezone_set("UTC");
$log_file = fopen("/usr/local/mgr5/var/". __MODULE__ .".log", "a");
$default_xml_string = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<doc/>\n";

function XMLToArray($xmlObject) {
	if (is_string($xmlObject)) return $xmlObject;
	$out = array();
	foreach ((array) $xmlObject as $index => $node) $out[$index] = XMLToArray($node);
	return $out;
}

function Debug($str) {
	global $log_file;
	fwrite($log_file, date("M j H:i:s") ." [". getmypid() ."] ". __MODULE__ ." \033[1;33mDEBUG ". $str ."\033[0m\n");
}

function DebugArray($arr) {
	global $log_file;
	fwrite($log_file, print_r($arr, true));
}

function Error($str) {
	global $log_file;
	fwrite($log_file, date("M j H:i:s") ." [". getmypid() ."] ". __MODULE__ ." \033[1;31mERROR ". $str ."\033[0m\n");
}

function tmErrorHandler($errno, $errstr, $errfile, $errline) {
	global $log_file;
	Error($errno .": ". $errstr .". In file: ". $errfile .". On line: ". $errline);
	return true;
}
set_error_handler("tmErrorHandler");

function tmExceprionHandler($exception) {
	global $log_file;
	Error($exception->getMessage());
	return true;
}
set_exception_handler("tmExceprionHandler");

function LocalQuery($function, $param, $auth = NULL) {
	$cmd = "/usr/local/mgr5/sbin/mgrctl -m billmgr -o xml " . escapeshellarg($function) . " ";
	foreach ($param as $key => $value) {
		$cmd .= escapeshellarg($key) . "=" . escapeshellarg($value) . " ";
	}
	if (!is_null($auth)) {
		$cmd .= " auth=" . escapeshellarg($auth);
	}
	$out = array();
	exec($cmd, $out);
	$out_str = "";
	foreach ($out as $value) {
		$out_str .= $value . "\n";
	}
	return simplexml_load_string($out_str);
}

function sendRequest($path, $args, $secretWord, $type)
{

	$api_url = "https://api.mivion.com/$path";
	if (is_array($args)) {
		$args = json_encode($args);
	}

	if ($curl = curl_init($api_url)) {
		curl_setopt($curl, CURLOPT_URL, $api_url);
		curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
		if($type == 'get') {
			curl_setopt($curl, CURLOPT_POST, 0);
		} else {
			curl_setopt($curl, CURLOPT_POST, 1);
			curl_setopt($curl, CURLOPT_POSTFIELDS, $args);
		}
		curl_setopt($curl, CURLOPT_CONNECTTIMEOUT, 30);
		curl_setopt($curl, CURLOPT_HTTPHEADER, array(
			'Content-Type: application/json', 'x-api-key: '.$secretWord
		));
		
		$out = curl_exec($curl);
		
		$httpCode = curl_getinfo($curl, CURLINFO_HTTP_CODE);

		curl_close($curl);
		if ($httpCode === 200) return $out;

		Error("sendRequest # enot error: Status - $httpCode. Message - $out");
		throw new Exception(
			"Возникла ошибка $httpCode при отправке запроса!", $httpCode
		);
		 
	} else {
		Error("sendRequest # enot: Cannot create connection to $api_url with args $args");
		throw new Exception(
			"Cannot create connection to $api_url with args $args", 404
		);
		
	}
}

function CgiInput($skip_auth = false) {
	if (!$skip_auth) {
		$input = $_SERVER["QUERY_STRING"];
		$param = array();
		parse_str($input, $param);
	} else {
		if ($_SERVER["REQUEST_METHOD"] == 'POST')
			$input = file_get_contents ("php://stdin",null,null,0,$_SERVER['CONTENT_LENGTH']);
		$param = json_decode($input,true);
	}

	if ($skip_auth == false && (!array_key_exists("auth", $param) || $param["auth"] == "")) {
		if (array_key_exists("billmgrses5", $_COOKIE)) {
			$cookies_bill = $_COOKIE["billmgrses5"];
			$param["auth"] = $cookies_bill;
		} elseif (array_key_exists("HTTP_COOKIE", $_SERVER)) {
			$cookies = explode("; ", $_SERVER["HTTP_COOKIE"]);
			foreach ($cookies as $cookie) {
				$param_line = explode("=", $cookie);
				if (count($param_line) > 1 && $param_line[0] == "billmgrses5") {
					$cookies_bill = explode(":", $param_line[1]);
					$param["auth"] = $cookies_bill[0];
				}
			}
		}
	}
	Debug("CgiInput: $input");

	return $param;
}

function getPaymentUrl($params,$secret_word) {

	$request = sendRequest('invoice/create', $params, $secret_word, 'POST');

	if (!$request) throw new Exception('enot: Ошибка создания инвойса.');

	$request = json_decode($request,true);

	return $request['data']['url'];
	
}


?>